from setuptools import setup
import os
import sys

setup(
    name='tvdb_rss',
    author='csm10495',
    author_email='csm10495@gmail.com',
    url='https://github.com/csm10495/tvdb_rss',
    version='0.0.4',
    packages=['tvdb_rss'],
    license='MIT License',
    python_requires='>=3.7',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    classifiers=[
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: POSIX',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
    ],
    include_package_data = True,
    install_requires=['csmlog', 'requests', 'feedgen'],
)


import datetime

from dataclasses import dataclass

@dataclass
class ShowInfo:
    show_name: str
    show_id: str = ''
    info_link: str = ''
    image_link: str = ''

@dataclass
class EpisodeInfo:
    show_info: ShowInfo
    episode_season: int
    episode_number: int
    first_aired: datetime.datetime
    episode_title: str = ''
    episode_description: str = ''
    info_link: str = ''
    image_link: str = ''

    def to_show_episode_string(self):
        return f'{self.show_info.show_name} - S{self.episode_season:02}E{self.episode_number:02} - {self.episode_title}'

    def get_available_image(self):
        return self.image_link or self.show_info.image_link

def to_dataclass(dc, _dict):
    return dc(**_dict)